# Changelog

## [0.2.8a1](https://github.com/OpenVoiceOS/ovos-PHAL/tree/0.2.8a1) (2024-11-25)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-PHAL/compare/0.2.7...0.2.8a1)

**Merged pull requests:**

- Update ovos-config requirement from \<1.0.0,\>=0.0.12 to \>=0.0.12,\<2.0.0 in /requirements [\#57](https://github.com/OpenVoiceOS/ovos-PHAL/pull/57) ([dependabot[bot]](https://github.com/apps/dependabot))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
